@@ -1,6 +1,6 @@
 na.approx <- function(object, ...) UseMethod("na.approx")
 
-na.approx.zoo <- function(object, x = index(object), xout, ..., na.rm = TRUE, along) {
+na.approx.zoo <- function(object, x = index(object), xout, ..., na.rm = TRUE, maxgap = Inf, along) {
 
     if (!missing(along)) {
         warning("along to be deprecated - use x instead")
@@ -27,13 +27,13 @@ na.approx.zoo <- function(object, x = index(object), xout, ..., na.rm = TRUE, al
         if (length(dim(objectm)) == 2) colnames(objectm) <- colnames(object)
         result <- window(objectm, index = xout)
     }
-    result[] <- na.approx.default(object, x = x, xout = xout, na.rm = FALSE, ...)
+    result[] <- na.approx.default(object, x = x, xout = xout, na.rm = FALSE, ..., maxgap = maxgap)
     if ((!missing(order.by) && !is.null(order.by)) || !missing.xout) {
         index(result) <- order.by
     }
 
     if (na.rm) {
-        result <- na.trim(result, is.na = "all")
+        result <- na.trim(result, is.na = "all", maxgap = maxgap)
     }
 
     result
@@ -104,7 +104,7 @@ na.approx.default <- function(object, x = index(object), xout = x, ..., na.rm =
     }
 
     if (na.rm) {
-        result <- na.trim(result, is.na = "all")
+        result <- na.trim(result, is.na = "all", maxgap = maxgap)
     }
 
     result
@@ -125,5 +125,6 @@ na.approx.ts <- function(object, ...) {
     naruns <- rle(is.na(x))
     naruns$values[naruns$lengths > maxgap] <- FALSE
     naok <- inverse.rle(naruns)
-    ifelse(naok, fill, x)
+    x[naok] <- fill[naok]
+    return(x)
 }
